Validity

Struct Validity 

pub struct Validity {
    pub not_before: ASN1Time,
    pub not_after: ASN1Time,
}

Fields

not_before: ASN1Timenot_after: ASN1Time

Implementations

Source

impl Validity

pub fn time_to_expiration(&self) -> Option<SignedDuration>

The time left before the certificate expires.

If the certificate is not currently valid, then None is returned. Otherwise, the Duration until the certificate expires is returned.

pub fn is_valid_at(&self, time: ASN1Time) -> bool

Check the certificate time validity for the provided date/time

pub fn is_valid(&self) -> bool

Check the certificate time validity