pub struct ServerIdentityPolicy { /* private fields */ }Expand description
A ValidationPolicy that checks whether the leaf certificate is authoritative
for a given hostname or IP address.
This policy is most commonly used to validate the leaf certificate presented by a server during a TLS handshake.
This policy implements the logic for service validation as specified by RFC 6125 (https://tools.ietf.org/search/rfc6125), which loosely speaking defines the common algorithm used for validating that an X.509 certificate is valid for a given service
Implementations