Module validator

Module validator 

Structs

PolicyFailure
A chain that was built but rejected by policy, and why.
Validator
Validates an X.509 certificate chain against a set of root certificates and a ValidationPolicy, using the crypto backend selected by this crate’s feature flags.

Type Aliases

ChainValidationResult
The result of validating a certificate chain.